@@ -378,7 +378,7 @@ class ConfusionMatrix():
             if normalize:
                 table = self.normalized_table
             html_file = open(name + ".html", "w", encoding="utf-8")
-            html_file.write(html_init())
+            html_file.write(HTML_INIT_TEMPLATE.format(description=OG_DESCRIPTION, image_url=OG_IMAGE_URL))
             html_file.write(html_dataset_type(self.binary, self.imbalance))
             html_file.write(
                 html_table(
@@ -403,7 +403,7 @@ class ConfusionMatrix():
                     class_list,
                     self.recommended_list,
                     alt_link))
-            html_file.write(html_end(PYCM_VERSION))
+            html_file.write(HTML_END_TEMPLATE.format(version=PYCM_VERSION))
             html_file.close()
             if address:
                 message = os.path.join(
@@ -631,6 +631,20 @@ class ConfusionMatrix():
                 TP=self.TP[i], FP=self.FP[i], FN=self.FN[i], TN=self.TN[i])
         return distance_dict
 
+    def dissimilarity_matrix(self):
+        """
+        Calculate dissimilarity matrix.
+
+        :return: dissimilarity matrix as dict
+        """
+        result = {class_name: dict(zip(self.classes, [0] * len(self.classes))) for class_name in self.classes}
+        matrix_array = self.to_array()
+        for class_index_1, class_name_1 in enumerate(self.classes):
+            for class_index_2, class_name_2 in enumerate(self.classes):
+                dist = int(sum(abs(matrix_array[class_index_1] - matrix_array[class_index_2])))
+                result[class_name_1][class_name_2] = dist
+        return result
+
     @metrics_off_check
     def CI(
             self,
