@@ -7,15 +7,6 @@ from .utils import rounder, sort_char_num
 import webbrowser
 
 
-def html_init():
-    """
-    Return HTML report file first lines.
-
-    :return: html_init as str
-    """
-    return HTML_INIT_TEMPLATE.format(OG_DESCRIPTION, OG_IMAGE_URL)
-
-
 def html_dataset_type(is_binary, is_imbalanced):
     """
     Return HTML report file dataset type.
@@ -26,19 +17,11 @@ def html_dataset_type(is_binary, is_imbalanced):
     :type is_imbalanced: bool
     :return: dataset_type as str
     """
-    result = "<h2>Dataset Type : </h2>\n"
-    balance_type = "Balanced"
-    class_type = "Binary Classification"
-    if is_imbalanced:
-        balance_type = "Imbalanced"
-    if not is_binary:
-        class_type = "Multi-Class Classification"
-    result += "<ul>\n<li>{0}</li>\n<li>{1}</li>\n</ul>\n".format(
-        class_type, balance_type)
-    result += "<p>{0}</p>\n".format(RECOMMEND_HTML_MESSAGE)
-    result += "<p>{0}</p>\n".format(RECOMMEND_HTML_MESSAGE2)
-
-    return result
+    return HTML_DATASET_TYPE_TEMPLATE.format(
+        balance_type="Imbalanced" if is_imbalanced else "Balanced",
+        class_type="Binary Classification" if is_binary else "Multi-Class Classification",
+        message1=RECOMMEND_HTML_MESSAGE,
+        message2=RECOMMEND_HTML_MESSAGE2)
 
 
 def color_check(color):
@@ -49,14 +32,10 @@ def color_check(color):
     :type color: tuple
     :return: color as list
     """
-    if isinstance(color, (tuple, list)):
-        if all(map(lambda x: isinstance(x, int), color)):
-            if all(map(lambda x: x < 256, color)):
-                return list(color)
-    if isinstance(color, str):
-        color_lower = color.lower()
-        if color_lower in TABLE_COLOR:
-            return TABLE_COLOR[color_lower]
+    if isinstance(color, (tuple, list)) and all(map(lambda x: isinstance(x, int) and x < 256, color)):
+        return list(color)
+    if isinstance(color, str) and color.lower() in TABLE_COLOR:
+        return TABLE_COLOR[color.lower()]
     return [0, 0, 0]
 
 
@@ -72,15 +51,10 @@ def html_table_color(row, item, color=(0, 0, 0)):
     :type color: tuple
     :return: background color as list [R, G, B]
     """
-    result = [0, 0, 0]
     color_list = color_check(color)
-    max_color = max(color_list)
     back_color_index = 255 - int((item / (sum(list(row.values())) + 1)) * 255)
-    for i in range(3):
-        result[i] = back_color_index - (max_color - color_list[i])
-        if result[i] < 0:
-            result[i] = 0
-    return result
+    color_offset = back_color_index - max(color_list)
+    return [max(0, color_offset + c) for c in color_list]
 
 
 def html_table(
@@ -114,8 +88,8 @@ def html_table(
     result += '<td>Actual</td>\n'
     result += '<td>Predict\n'
     table_size = str((len(classes) + 1) * 7) + "em"
-    result += '<table style="border:1px solid black;border-collapse: collapse;height:{0};width:{0};">\n'\
-        .format(table_size)
+    result += '<table style="border:1px solid black;border-collapse: collapse;height:{size};width:{size};">\n'\
+        .format(size=table_size)
     result += '<tr style="text-align:center;">\n<td></td>\n'
     part_2 = ""
     for i in classes:
@@ -135,8 +109,8 @@ def html_table(
             back_color = html_table_color(table[i], item, rgb_color)
             if min(back_color) < 128:
                 color = "white"
-            part_2 += '<td style="background-color:rgb({0},{1},{2});color:{3};padding:10px;height:7em;width:7em;">'.format(
-                str(back_color[0]), str(back_color[1]), str(back_color[2]), color) + str(item) + '</td>\n'
+            part_2 += '<td style="background-color:rgb({r},{g},{b});color:{color};padding:10px;height:7em;width:7em;">'.format(
+                r=str(back_color[0]), g=str(back_color[1]), b=str(back_color[2]), color=color) + str(item) + '</td>\n'
         part_2 += "</tr>\n"
     result += '</tr>\n'
     part_2 += "</table>\n</td>\n</tr>\n</table>\n"
@@ -182,12 +156,12 @@ def html_overall_stat(
         if i in recommended_list:
             background_color = RECOMMEND_BACKGROUND_COLOR
         result += '<tr style="text-align:center;">\n'
-        result += '<td style="border:1px solid black;padding:4px;text-align:left;background-color:{};"><a href="'.format(
-            background_color) + document_link + PARAMS_LINK[i] + '" style="text-decoration:None;">' + str(i) + '</a></td>\n'
+        result += '<td style="border:1px solid black;padding:4px;text-align:left;background-color:{color};"><a href="'.format(
+            color=background_color) + document_link + PARAMS_LINK[i] + '" style="text-decoration:None;">' + str(i) + '</a></td>\n'
         if i in BENCHMARK_LIST:
             background_color = BENCHMARK_COLOR[i][overall_stat[i]]
-            result += '<td style="border:1px solid black;padding:4px;background-color:{};">'.format(
-                background_color)
+            result += '<td style="border:1px solid black;padding:4px;background-color:{color};">'.format(
+                color=background_color)
         else:
             result += '<td style="border:1px solid black;padding:4px;">'
         result += rounder(overall_stat[i], digit) + '</td>\n'
@@ -243,13 +217,13 @@ def html_class_stat(
         if i in recommended_list:
             background_color = RECOMMEND_BACKGROUND_COLOR
         result += '<tr style="text-align:center;border:1px solid black;border-collapse: collapse;">\n'
-        result += '<td style="border:1px solid black;padding:4px;border-collapse: collapse;background-color:{};"><a href="'.format(
-            background_color) + document_link + PARAMS_LINK[i] + '" style="text-decoration:None;">' + str(i) + '</a></td>\n'
+        result += '<td style="border:1px solid black;padding:4px;border-collapse: collapse;background-color:{color};"><a href="'.format(
+            color=background_color) + document_link + PARAMS_LINK[i] + '" style="text-decoration:None;">' + str(i) + '</a></td>\n'
         for j in classes:
             if i in BENCHMARK_LIST:
                 background_color = BENCHMARK_COLOR[i][class_stat[i][j]]
-                result += '<td style="border:1px solid black;padding:4px;border-collapse: collapse;background-color:{};">'.format(
-                    background_color)
+                result += '<td style="border:1px solid black;padding:4px;border-collapse: collapse;background-color:{color};">'.format(
+                    color=background_color)
             else:
                 result += '<td style="border:1px solid black;padding:4px;border-collapse: collapse;">'
             result += rounder(class_stat[i][j], digit) + '</td>\n'
@@ -263,17 +237,6 @@ def html_class_stat(
     return result
 
 
-def html_end(version):
-    """
-    Return HTML report file end lines.
-
-    :param version: pycm version
-    :type version: str
-    :return: html_end as str
-    """
-    return HTML_END_TEMPLATE.format(version)
-
-
 def pycm_help():
     """
     Print pycm details.
